@@ -85,8 +85,12 @@ def bit_value(state, address, bit):
     return temp[len(temp)-1-bit]
 
 def change_bit_value(state, address, bit, value):
+    if value:
+        ch = '1'
+    else:
+        ch = '0'
     temp = format(state[address], '016b')
-    temp[len(temp)-1-bit] = value
+    temp[len(temp)-1-bit] = ch
     return int(temp, 2)
 
 def date_as_number(date):
